### Packaged Plugin Licenses
The following dependencies are packaged with
salt for Windows with their corresponding licenses:

| Module    | License |
|-----------|---------|
| backports.ssl-match-hostname | PSF |
| certifi | ISC |
| cffi | MIT |
| CherryPy | BSD |
| cryptography | BSD |
| gitdb | BSD |
| GitPython | BSD |
| idna | BSD-like |
| ioloop | MIT |
| ipaddress | PSF |
| Jinja2 | BSD |
| libnacl | Apache |
| lxml | BSD |
| Mako | MIT |
| MarkupSafe | BSD |
| msgpack | Apache 2.0 |
| pip | MIT |
| psutil | BSD |
| pyasn1 | BSD |
| pycparser | BSD |
| pycurl | LGPL + MIT |
| PyMySQL | MIT |
| PyOpenSSL | Apache 2.0 |
| python-certifi-win32 | BSD |
| python-dateutil | Simplified BSD |
| python-gnupg | BSD |
| pywin32 | PSF |
| PyYAML | MIT |
| pyzmq | LGPL + BSD |
| requests | Apache 2.0 |
| setuptools | MIT |
| singledispatch | MIT |
| smmap | BSD |
| timelib | ZLIB/PHP |
| tornado | Apache 2.0 |
| wheel | MIT |
| WMI | MIT |
